<a name="readme-top"></a>


<!-- PROJECT SHIELDS -->
<!--
*** I'm using markdown "reference style" links for readability.
*** Reference links are enclosed in brackets [ ] instead of parentheses ( ).
*** See the bottom of this document for the declaration of the reference variables
*** for contributors-url, forks-url, etc. This is an optional, concise syntax you may use.
*** https://www.markdownguide.org/basic-syntax/#reference-style-links
-->



<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/Alieyeh/hypehd/">
    <img src="./imgs/Animated Logo 500x500 px.gif" alt="Logo" width="300" height="300">
  </a>

  <h3 align="center">HYPEHD</h3>

  <p align="center">
    A package to aid in data exploration for health data.
    <br />
    <a href="https://github.com/Alieyeh/hypehd/issues">Report Bug</a>
    ·
    <a href="https://github.com/Alieyeh/hypehd/issues">Request Feature</a>
  </p>
</div>



<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#dependencies">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#documentation">Usage</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>



<!-- ABOUT THE PROJECT -->
## About The Project

HYPEHD is a Python package that provides easy to use functions, designed to make the exploration of health data easier for people with various levels of python experience, but primarily for those who are less experienced. This package aims to be a tool for real-world and practical data analysis, assisting in reaching a quicker understanding of various health related data.

<p align="right">(<a href="#readme-top">back to top</a>)</p>



### Dependencies
- Python 3.7 (with the following packages)
    - numpy 1.19.4
    - matplotlib 3.5.3
    - seaborn 0.11.0
    - pandas 1.0.1
    - scipy.stats 1.4.1
    - sklearn.cluster 0.22.1
    - lifelines 0.27.4


<p align="right">(<a href="#readme-top">back to top</a>)</p>



<!-- GETTING STARTED -->
## Getting Started

The source code is currently hosted on GitHub at: [https://github.com/Alieyeh/hypehd](https://github.com/Alieyeh/hypehd)
Running requires:
- Python>=3.7

### Installation

Binary installers for the latest released version are available at the Test Python Package Index (TestPyPI)
[https://test.pypi.org/project/hypehd/#description](https://test.pypi.org/project/hypehd/#description)

```shell
python -m pip install --index-url https://test.pypi.org/simple/ --extra-index-url https://pypi.org/simple hypehd
```

For dependancies, you can also download the conda environment from this github and run it by issuing the following command on a terminal
```shell
git clone https://github.com/Alieyeh/hypehd
cd hypehd
conda update conda
conda create -f codenv.yml
conda activate hypehd_env
```

<p align="right">(<a href="#readme-top">back to top</a>)</p>



<!-- Documentation -->
## Documentation
The official documentation can be found on: 
[https://hypehd.readthedocs.io/en/latest/](https://hypehd.readthedocs.io/en/latest/)<br>
On the website, users can find examples, API and more detailed information about this package.

<p align="right">(<a href="#readme-top">back to top</a>)</p>



<!-- CONTACT -->
## Contact

Project Link: [https://github.com/Alieyeh/hypehd](https://github.com/Alieyeh/hypehd)

<p align="right">(<a href="#readme-top">back to top</a>)</p>

